@@ -27,13 +27,13 @@ class WorkspaceRun:
         parser.add_argument('--codePath', default=None)
         parser.add_argument('--stopFlag', default=False)
         parser.add_argument('--stopTimeout', default=600)
-        parser.add_argument('--args', default='')
+        parser.add_argument('--argument', default='')
 
         args, unknown = parser.parse_known_args()
         args_dict = vars(args)
 
         if not args_dict['args'] == '':
-            self.custom_args = + args_dict['args']\
+            self.custom_args = args_dict['args']\
                 .replace('[[:space:]]', " ").replace('[[:equal:]]', '=').replace('[[:hyphen:]]', '--')
 
         self.code_path = args_dict['codePath']
