@@ -12,5 +12,5 @@ Tree_type_2 = ['LightGBM', 'lightgbm']
 Linear = ['Linear', 'Logistic', 'Ridge', 'SGD', 'ElasticNet', 'Lars', 'Lasso',
           'OrthogonalMatchingPursuit', 'ARD', 'BayesianRidge', 'Huber', 'RANSAC', 'TheilSen',
           'Poisson', 'Tweedie', 'Gamma', 'PassiveAggresive', 'lars', 'lasso', 'orthogonal_mp',
-          'ridge', 'LogisticRegression']
+          'ridge', 'LogisticRegression', 'LinearRegression']
 
